@@ -3,12 +3,12 @@ use strict;
 
 use base qw(Pod::Abstract::Filter);
 
-our $VERSION = '0.19';
+our $VERSION = '0.26';
 
 =head1 NAME
 
-Pod::Abstract::Filter::clear_podcmds - paf command to remove =pod commands
-from the begining of Pod blocks.
+Pod::Abstract::Filter::clear_podcmds - Remove =pod commands from the
+begining of Pod blocks.
 
 =cut
 
@@ -33,11 +33,11 @@ sub filter {
 
 =head1 AUTHOR
 
-Ben Lilburne <bnej@mac.com>
+Ben Lilburne <bnej80@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 Ben Lilburne
+Copyright (C) 2009-2025 Ben Lilburne
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
