@@ -5,12 +5,12 @@ use warnings;
 use base qw(Pod::Abstract::Filter);
 use Pod::Abstract::BuildNode qw(node);
 
-our $VERSION = '0.19';
+our $VERSION = '0.26';
 
 =head1 NAME
 
-Pod::Abstract::Filter::find - paf command to find specific nodes that
-contain a string.
+Pod::Abstract::Filter::find - Find specific nodes that contain a
+string.
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ head4 or list item, we're fine. If you use head1 then it won't be useful.
 In order to be useful as an end user tool, head1 nodes (...) are added
 between the found nodes. This stops perldoc from dying with no
 documentation. These can be easily stripped using:
-C<<$pa->select('/head1')>>, then hoist and detach, or reparent to other
+C<< $pa->select('/head1') >>, then hoist and detach, or reparent to other
 Node types.
 
 A good example of this working as intended is:
@@ -85,11 +85,11 @@ sub filter {
 
 =head1 AUTHOR
 
-Ben Lilburne <bnej@mac.com>
+Ben Lilburne <bnej80@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 Ben Lilburne
+Copyright (C) 2009-2025 Ben Lilburne
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
