@@ -4,12 +4,12 @@ use warnings;
 
 use base qw(Pod::Abstract::Filter);
 
-our $VERSION = '0.19';
+our $VERSION = '0.26';
 
 =head1 NAME
 
-Pod::Abstract::Filter::unoverlay - paf command to remove "overlay" blocks
-from a Pod document, as created by the paf overlay command.
+Pod::Abstract::Filter::unoverlay - Remove "overlay" blocks from a Pod
+document, as created by the paf overlay command.
 
 =begin :overlay
 
@@ -64,11 +64,11 @@ sub filter {
 
 =head1 AUTHOR
 
-Ben Lilburne <bnej@mac.com>
+Ben Lilburne <bnej80@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 Ben Lilburne
+Copyright (C) 2009-2025 Ben Lilburne
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
